#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stack
version:              2.9.3.1
visibility:           public
id:                   stack-2.9.3.1-74QoVWlqAMMGO2ix3mvBsI
key:                  stack-2.9.3.1-74QoVWlqAMMGO2ix3mvBsI
license:              BSD-3-Clause
maintainer:           manny@fpcomplete.com
author:               Commercial Haskell SIG
homepage:             http://haskellstack.org
synopsis:             The Haskell Tool Stack
description:
    Please see the documentation at <https://docs.haskellstack.org>
    for usage information.

    If building a '\''stack'\'' executable for distribution, please download the
    source code from <https://github.com/commercialhaskell/stack/releases>
    and build it using Stack itself in order to ensure identical behaviour
    to official binaries.  This package on Hackage is provided for convenience
    and bootstrapping purposes.

    Note that the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.

category:             Development
abi:                  f8e83ab40f3f3589ab22d9fa7c3dcec5
exposed:              True
exposed-modules:
    Control.Concurrent.Execute Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.Monoid.Map Network.HTTP.StackClient Options.Applicative.Args
    Options.Applicative.Builder.Extra Options.Applicative.Complicated
    Path.CheckInstall Path.Extra Path.Find Paths_stack Stack.Build
    Stack.Build.Cache Stack.Build.ConstructPlan Stack.Build.Execute
    Stack.Build.Haddock Stack.Build.Installed Stack.Build.Source
    Stack.Build.Target Stack.BuildPlan Stack.Clean Stack.Config
    Stack.Config.Build Stack.Config.Docker Stack.Config.Nix
    Stack.ConfigCmd Stack.Constants Stack.Constants.Config
    Stack.Coverage Stack.DefaultColorWhen Stack.Docker Stack.Dot
    Stack.FileWatch Stack.GhcPkg Stack.Ghci Stack.Ghci.Script
    Stack.Hoogle Stack.IDE Stack.Init Stack.List Stack.Lock Stack.Ls
    Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.Completion
    Stack.Options.ConfigParser Stack.Options.DockerParser
    Stack.Options.DotParser Stack.Options.ExecParser
    Stack.Options.GhcBuildParser Stack.Options.GhcVariantParser
    Stack.Options.GhciParser Stack.Options.GlobalParser
    Stack.Options.HaddockParser Stack.Options.HpcReportParser
    Stack.Options.LogLevelParser Stack.Options.NewParser
    Stack.Options.NixParser Stack.Options.PackageParser
    Stack.Options.ResolverParser Stack.Options.SDistParser
    Stack.Options.ScriptParser Stack.Options.TestParser
    Stack.Options.UploadParser Stack.Options.Utils Stack.Package
    Stack.PackageDump Stack.Path Stack.Prelude Stack.Runners
    Stack.SDist Stack.Script Stack.Setup Stack.Setup.Installed
    Stack.SetupCmd Stack.SourceMap Stack.Storage.Project
    Stack.Storage.User Stack.Storage.Util Stack.Types.Build
    Stack.Types.Compiler Stack.Types.CompilerBuild Stack.Types.Config
    Stack.Types.Config.Build Stack.Types.Docker Stack.Types.GhcPkgId
    Stack.Types.NamedComponent Stack.Types.Nix Stack.Types.Package
    Stack.Types.PackageName Stack.Types.Resolver Stack.Types.SourceMap
    Stack.Types.TemplateName Stack.Types.Version Stack.Unpack
    Stack.Upgrade Stack.Upload System.Info.ShortPathName
    System.Permissions System.Process.Pager System.Terminal

hidden-modules:
    Path.Extended Stack.ComponentFile Stack.PackageFile
    Stack.Types.Cache Stack.Types.Dependency Stack.Types.PackageFile
    Stack.Types.Storage System.Uname

import-dirs:          /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stack
hs-libraries:         HSstack-2.9.3.1-74QoVWlqAMMGO2ix3mvBsI
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-H9vL3B7Q1M887LyJp8DI7B
    annotated-wl-pprint-0.7.0-GFWp72SduKx5Zv0YaM2sPQ
    ansi-terminal-1.1-2cyMlQgd5fy5kJDD0z3e11 array-0.5.6.0
    async-2.2.6-96ghOoZ84FP9drk9Igmfsb
    attoparsec-0.14.4-E3k9gMxUgUu8YEK3rXCpQl base-4.18.2.1
    base64-bytestring-1.2.1.0-Bc6E69C4m3ECPtW5iM3aze
    bytestring-0.11.5.3 casa-client-0.0.4-HbWLtzryXxn1XsZL5M63US
    casa-types-0.0.3-1ZAXvjqHqO24Phu8aE4e6i
    colour-2.3.7-H4UtrQEP9cPAl0aIJUuIlG
    conduit-1.3.6.1-8VvDzdYCjdmI3bZURbw9Mg
    conduit-extra-1.3.8-CJ5tlfsgh991qVydi8sBUY containers-0.6.7
    crypton-1.0.5-LmyGk2jR8reH5FpmkweY6o
    crypton-conduit-0.2.3-Gjj3HaeeAYT1NxvKm81hbk deepseq-1.4.8.1
    directory-1.3.8.5 echo-0.1.4-BCPf0iNIcqQJp7PonIPBEA
    exceptions-0.10.7 extra-1.7.16-DKc8qfrWbGW5PlG5evlQA7
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    filelock-0.1.1.9-9iFEViFltK6DhrWUbFFVCn filepath-1.4.300.1
    fsnotify-0.4.4.0-Yd9suUqsiwLckUiPrDoiD
    generic-deriving-1.14.7-EdpMS6VUjSWAYwhkxCiLC8
    hackage-security-0.6.3.2-HuFAnVttWAGDUcPcZiOccj
    hashable-1.4.7.0-5StsBkxyCbNDS76Iywepp0
    hi-file-parser-0.1.8.0-2ViwwoG5PULII1BTynIzOL
    hpack-0.38.0-8NFW6JxsLnID8Q1WhJFN0e hpc-0.6.2.0
    http-client-0.7.19-84YeTfMA7sUG2b5dJlJyNT
    http-client-tls-0.3.6.4-AMICySyXtyb5XWO9dTvch8
    http-conduit-2.3.9.1-GN8shez2AjKcvQYIkpF1x
    http-download-0.2.1.0-EIq3Uv0PfUd2ohOLPKxshN
    http-types-0.12.4-1bxZkGnF9y3EyYShq7fWol
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    mintty-0.1.4-CFeOovjDLzzJb68ZeM2nF
    mono-traversable-1.0.21.0-1pOZeKMwfBt9EDgygc84GE mtl-2.3.1
    mustache-2.4.3.1-4FaGm2w4vTfBvYw8d3AAYZ
    neat-interpolation-0.5.1.4-4KK7IF516gOGcg5T8Bgy3U
    network-uri-2.6.4.2-Lv4CPfOXEbY6n3C00bvBRa
    open-browser-0.2.1.1-LxNiN4VEneo8bxQiPfYDai
    optparse-applicative-0.18.1.0-6WkkIcukFLq8Du5eXOxEQL
    pantry-0.8.3-LMujxqSQVUuBTqtsnUhwpt
    path-0.9.6-IbXPcXcmzBw5O9k2ryCpL8
    path-io-1.8.2-HiaYwrLHI4EFbjWKNHXmPe
    persistent-2.14.6.1-KgamJIxsTywnllg9tNdns
    persistent-sqlite-2.13.3.0-40MTGPBaYfh6M8OsDmTKWL pretty-1.1.3.6
    primitive-0.9.1.0-KmbTEov2Wra5pynu7RyLhl process-1.6.19.0
    project-template-0.2.1.0-AH8YMVvXEdqIGyQvzplDfB
    random-1.2.1.3-44WPcS98Ep6JdxWOslKx91
    retry-0.9.3.1-HOrJSIFHByv4wS1KyFnovI
    rio-0.1.25.0-65HpbPks4rkIrNqtDaCNZk
    rio-prettyprint-0.1.9.0-IadlqZdth9C23eQgsJX7qG
    split-0.2.5.1-FQ4kT9wgw7JDP8h2QeY4XG stm-2.5.1.0
    streaming-commons-0.2.3.1-75jTHMQjsonDB0bzkEpT0v
    tar-0.6.0.0-CTap7vmgCZkVJ6nLTYKyK template-haskell-2.20.0.0
    temporary-1.3-3DMSJA7Ya3nISoRGwgvVW text-2.0.2
    text-metrics-0.3.3-K936D7irijf4ZJ8zBjL9Gu
    th-reify-many-0.1.10-4jlEvmoTYj34IFSbgNqvzM time-1.12.2
    tls-2.0.6-ExRbrBKJoLjDbEiNjmDy1o transformers-0.6.1.0
    typed-process-0.2.13.0-3acCyXNeKz86sG7rYzTL9C
    unicode-transforms-0.4.0.1-IjDrs5cLaSI5v7UTvBEc6x unix-2.8.4.0
    unix-compat-0.7.4.1-JfBZcOE4KkR1xKg0EkVJAF
    unliftio-0.2.25.1-FGD5skDxYg680smWpwqc4D
    unordered-containers-0.2.21-L1oX0JcZSx93XslkjWFdin
    vector-0.13.2.0-Lo47YTUMDVEGGONIqhDOGa
    yaml-0.11.11.2-2KdCqsazgpb7ICScUPwACD
    zip-archive-0.4.3.2-8o1kz8hrN9CCvXo5lGmuOA
    zlib-0.7.1.1-6VmR3caixVw1oiWgdpvEpd

haddock-interfaces:   /usr/share/doc/stack/html/stack.haddock
haddock-html:         /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

